``plover.machine.keyboard_capture`` -- Keyboard capture
================================================================

.. automodule:: plover.machine.keyboard_capture
   :no-members:

.. autoclass:: plover.machine.keyboard_capture.Capture

   .. automethod:: start

   .. automethod:: cancel

   .. automethod:: suppress

   The following methods are available to implementors to hook into the
   keyboard capture system:

   .. automethod:: key_down

   .. automethod:: key_up
